import { useEffect, useState } from 'react';
import { Dropdown } from '@fluentui/react';
import React from "react";
import { lang } from '@wiberg/formbuilder';
export const DynamicPredefinedArrayField = (props) => {
    const [value, setValue] = useState(props.value);
    useEffect(() => setValue(props.value), [props.value]);
    const [options, setOptions] = useState();
    useEffect(() => {
        // async fetch of values
        let asyncGetter = props.config?.predefinedOptions?.optionsAsync;
        if (asyncGetter != null) {
            setOptions([{ key: -1, text: lang.texts.areas.common.loading }]);
            let fetch = async () => {
                try {
                    const options = await asyncGetter(props.parent);
                    setOptions(options);
                }
                catch (error) {
                    setOptions([{ key: -1, text: lang.texts.areas.form.dropdownFailedFetch }]);
                    console.error(error);
                }
            };
            fetch();
        }
        // use static values
        else
            setOptions(props.config?.predefinedOptions?.options);
    }, [props.config?.predefinedOptions]);
    const onChange = (option) => {
        if (option === undefined)
            return;
        let newValue = undefined;
        if (props.config?.multiSelect) {
            let parsed = value ?? [];
            let clone = [...parsed];
            if (option.selected)
                clone.push(option.key);
            else {
                const currIndex = clone.indexOf(option.key);
                if (currIndex > -1) {
                    clone.splice(currIndex, 1);
                }
            }
            newValue = clone;
        }
        else
            newValue = option.key;
        props.onChange(newValue);
    };
    return React.createElement(Dropdown, { disabled: props.disabled, multiSelect: props.config?.multiSelect ?? false, options: options ?? [], selectedKey: props.config?.multiSelect ? undefined : value, selectedKeys: props.config?.multiSelect ? value : undefined, onChange: (event, option, index) => onChange(option), errorMessage: props.errorMessage });
};
//# sourceMappingURL=DynamicPredefinedArrayField.js.map