import { useRef, useEffect } from 'react';
import { DelayedSearchBox } from './DelayedSearchBox';
import React from "react";
export const Searcher = props => {
    let searchText = useRef("");
    let highlightInProgess = useRef(false);
    useEffect(() => {
        if (props.filterOnItemsChange && searchText.current)
            filterItems(searchText.current);
    }, [props.items]);
    useEffect(() => {
        filterItems(searchText.current, true);
    }, [props.customSearchFunction]);
    useEffect(() => {
        let newValueParts = searchText.current.split(" ");
        highlightSearchText(newValueParts);
    }, [props.highLightElements]);
    const filterItems = (value, initial) => {
        if (!props.items || !props.items.length)
            return;
        if (props.minCharsForSearch != null && value !== undefined && value.length != 0 && value.length < props.minCharsForSearch)
            return;
        let newValueParts = value.split(" ");
        let filteredItems = [];
        if (props.customSearchFunction)
            filteredItems = props.customSearchFunction(newValueParts);
        else {
            let propertyGetter = (item, field) => item[field];
            filteredItems = props.items.filter(item => props.searchFields.some(sf => newValueParts.every(part => new RegExp(`${part}`, "i").test(propertyGetter(item, sf)))));
        }
        if (!initial)
            props.onSearch(filteredItems, value);
        if (props.enableTextHighlight && props.highLightElements)
            highlightSearchText(newValueParts);
    };
    const highlightSearchText = (searchTextParts) => {
        if (!props.highLightElements)
            return;
        if (highlightInProgess.current)
            return;
        highlightInProgess.current = true;
        // clear highlight on new search
        var highlightElements = props.highLightElements();
        highlightElements.forEach(_ => _.innerHTML = _.innerHTML.replace(/(<span class="tp-searcher-highlight">|<\/span>)/igm, ""));
        // set highlights
        highlightElements.forEach((_) => {
            let html = _.innerHTML;
            const tagsRegEx = new RegExp('(<.+?>|&\\w+;)');
            searchTextParts.forEach((searchText, idx) => {
                let minChars = props.minCharsForSearch ?? 0;
                if (searchText.length < minChars)
                    return;
                const htmlParts = html.split(tagsRegEx).filter(Boolean);
                html = htmlParts.map(item => tagsRegEx.test(item)
                    ? item
                    : item.replace(new RegExp(`(${searchText})`, 'ig'), `<span class="tp-searcher-highlight">$1</span>`)).join('');
            });
            _.innerHTML = html;
        });
        highlightInProgess.current = false;
    };
    return React.createElement(DelayedSearchBox, { className: `tp-panel-searchbox ${props.className ? props.className : ""}`, delay: props.delay ?? 300, disabled: props.disabled, searchPlaceHolder: props.searchPlaceHolder, onChange: (text) => { searchText.current = text ?? ""; filterItems(text ?? ""); }, onFocus: props.onInputFocus });
};
//# sourceMappingURL=Searcher.js.map